@@ -2,7 +2,7 @@
 from enum import Enum, IntEnum
 
 
-class RPErrorHandler():
+class RPErrorHandler:
     """Remote Play Errors."""
 
     def __init__(self):
@@ -18,15 +18,17 @@ class RPErrorHandler():
 
     class Type(IntEnum):
         """Enum for errors."""
-        REGIST_FAILED = 0x80108b09
-        INVALID_PSN_ID = 0x80108b02
-        RP_IN_USE = 0x80108b10
-        CRASH = 0x80108b15
-        RP_VERSION_MISMATCH = 0x80108b11
-        UNKNOWN = 0x80108bff
+
+        REGIST_FAILED = 0x80108B09
+        INVALID_PSN_ID = 0x80108B02
+        RP_IN_USE = 0x80108B10
+        CRASH = 0x80108B15
+        RP_VERSION_MISMATCH = 0x80108B11
+        UNKNOWN = 0x80108BFF
 
     class Message(Enum):
         """Messages for Error."""
+
         REGIST_FAILED = "Registering Failed"
         INVALID_PSN_ID = "PSN ID does not exist on host"
         RP_IN_USE = "Another Remote Play session is connected to host"
