@@ -7,7 +7,7 @@ import time
 from typing import Union
 from base64 import b64decode, b64encode
 from concurrent.futures import ThreadPoolExecutor
-from enum import IntEnum
+from enum import IntEnum, auto
 from functools import partial
 from struct import pack_into
 
@@ -17,6 +17,7 @@ from pyee import ExecutorEventEmitter
 
 from pyremoteplay.receiver import AVReceiver
 from .const import (
+    DEFAULT_SESSION_TIMEOUT,
     FPS,
     OS_TYPE,
     RP_CRYPT_SIZE,
@@ -31,7 +32,7 @@ from .const import (
     Quality,
 )
 from .crypt import SessionCipher
-from .ddp import async_get_status, wakeup
+from .ddp import async_get_status, wakeup as ddp_wakeup
 from .errors import RemotePlayError, RPErrorHandler
 from .keys import (
     SESSION_KEY_0_PS4,
@@ -184,11 +185,16 @@ class Session:
     :param hdr: Uses HDR if True. Has no effect if codec is 'h264'
     """
 
-    STATE_INIT = "init"
-    STATE_READY = "ready"
-    STATE_STOP = "stop"
     HEADER_LENGTH = 8
 
+    class State(IntEnum):
+        """State Enums."""
+
+        INIT = auto()
+        RUNNING = auto()
+        READY = auto()
+        STOP = auto()
+
     class MessageType(IntEnum):
         """Enum for Message Types."""
 
@@ -225,7 +231,11 @@ class Session:
 
         def close(self):
             """Close Transport."""
-            self._transport.close()
+            try:
+                self._transport.close()
+            # pylint: disable=broad-except
+            except Exception as error:
+                _LOGGER.warning("Session Transport did not close; Error: %s", error)
 
         @property
         def transport(self) -> asyncio.BaseTransport:
@@ -234,7 +244,9 @@ class Session:
 
     def __repr__(self):
         return (
-            f"<RP Session host={self._host} "
+            f"{str(self.__class__)[:-1]} "
+            f"host={self.host} "
+            f"state={self.state.name} "
             f"resolution={self.resolution} "
             f"fps={self.fps}>"
         )
@@ -266,7 +278,7 @@ class Session:
         self._sock = None
         self._hb_last = 0
         self._cipher = None
-        self._state = Session.STATE_INIT
+        self._state = Session.State.INIT
         self._stream = None
         self._receiver = None
         self._events = ExecutorEventEmitter()
@@ -278,7 +290,7 @@ class Session:
 
         self._ready_event = None
         self._stop_event = None
-        self._stream_ready_event = None
+        self._ready_event = None
 
         self._quality = Quality.parse(quality)
         self._fps = FPS.parse(fps)
@@ -546,7 +558,8 @@ class Session:
 
     def standby(self):
         """Set host to standby."""
-
+        if not self.is_ready:
+            raise RemotePlayError("Session is not ready")
         msg = self._build_msg(Session.MessageType.STANDBY)
         self._send(msg)
         _LOGGER.info("Sending Standby")
@@ -555,14 +568,13 @@ class Session:
     def _send_wakeup(self):
         """Wakeup Host."""
         regist_key = format_regist_key(self._regist_key)
-        wakeup(self.host, regist_key, host_type=self.type)
+        ddp_wakeup(self.host, regist_key, host_type=self.type)
 
     async def start(self, wakeup=True, autostart=True) -> bool:
         """Start Session/RP Session."""
         _LOGGER.info("Session Started")
         self._ready_event = asyncio.Event()
         self._stop_event = asyncio.Event()
-        self._stream_ready_event = asyncio.Event()
 
         self.events.on("av_ready", self._init_av_handler)
 
@@ -586,7 +598,7 @@ class Session:
                 self.error = "Auth Failed."
             return False
         _LOGGER.info("Session Auth Success")
-        self._state = Session.STATE_READY
+        self._state = Session.State.RUNNING
         _, self._protocol = await self.loop.connect_accepted_socket(
             lambda: Session.Protocol(self), self._sock
         )
@@ -597,14 +609,14 @@ class Session:
 
     def stop(self):
         """Stop Session."""
-        if self.state == Session.STATE_STOP:
+        if self.state == Session.State.STOP:
             _LOGGER.debug("Session already stopping")
             return
         _LOGGER.debug("Session Received Stop Signal")
-        if self._stream:
-            self._stream.stop()
         if self._stop_event:
             self._stop_event.set()
+        if self._stream:
+            self._stream.stop()
         if self._tasks:
             for task in self._tasks:
                 task.cancel()
@@ -636,6 +648,39 @@ class Session:
         if old_receiver:
             old_receiver.close()
 
+    def _set_ready(self):
+        self._state = Session.State.READY
+
+    def wait(self, timeout: Union[float, int] = DEFAULT_SESSION_TIMEOUT) -> bool:
+        """Wait for session to be ready. Return True if session becomes ready.
+
+        Blocks until timeout exceeded or when session is ready.
+
+        :param timeout: Timeout in seconds.
+        """
+        start = time.time()
+        while time.time() - start > timeout and not self.is_ready:
+            if self.is_stopped:
+                return False
+            time.sleep(0.01)
+        return self.is_ready
+
+    async def async_wait(
+        self, timeout: Union[float, int] = DEFAULT_SESSION_TIMEOUT
+    ) -> bool:
+        """Wait for session to be ready. Return True if session becomes ready.
+
+        Waits until timeout exceeded or when session is ready.
+
+        :param timeout: Timeout in seconds.
+        """
+        start = time.time()
+        while time.time() - start < timeout and not self.is_ready:
+            if self.is_stopped:
+                return False
+            await asyncio.sleep(0.01)
+        return self.is_ready
+
     @property
     def host(self) -> str:
         """Return host address."""
@@ -647,23 +692,28 @@ class Session:
         return self._type
 
     @property
-    def state(self) -> str:
+    def state(self) -> State:
         """Return State."""
         if self._stop_event is None:
             return self._state
         if self._stop_event.is_set():
-            return Session.STATE_STOP
+            return Session.State.STOP
         return self._state
 
+    @property
+    def is_ready(self) -> bool:
+        """Return True if ready for user interaction."""
+        return self.state == Session.State.READY
+
     @property
     def is_running(self) -> bool:
         """Return True if running."""
-        return self.state == Session.STATE_READY
+        return self.state in (Session.State.READY, Session.State.RUNNING)
 
     @property
     def is_stopped(self) -> bool:
         """Return True if stopped."""
-        return self.state == Session.STATE_STOP
+        return self.state == Session.State.STOP
 
     @property
     def session_id(self) -> bytes:
@@ -671,20 +721,15 @@ class Session:
         return self._session_id
 
     @property
-    def stream(self):
+    def stream(self) -> RPStream:
         """Return Stream."""
         return self._stream
 
     @property
-    def stop_event(self):
+    def stop_event(self) -> asyncio.Event:
         """Return Stop Event."""
         return self._stop_event
 
-    @property
-    def stream_ready_event(self) -> asyncio.Event:
-        """Return Stream Ready Event."""
-        return self._stream_ready_event
-
     @property
     def resolution(self) -> Resolution:
         """Return resolution."""
